==> digikam-3.0.0-beta1.tar.bz2: digikam-3.0.0-beta1/extra/kipi-plugins/photolayoutseditor/plugin/kipiplugin_photolayoutseditor.desktop.cmake <==
[Desktop Entry]
Name=Photo Layouts Editor
Name[ca]=Editor de presentacions de foto
Name[ca@valencia]=Editor de formats de foto
Name[cs]=Editor rozvržení snímků
Name[da]=Editor til fotolayout
Name[de]=Fotolayout-Editor
Name[el]=Επεξεργαστής διατάξεων φωτογραφιών
Name[es]=Editor de formatos de fotos
Name[et]=Fotode paigutusredaktor
Name[gl]=Editor das disposicións das fotos
Name[hu]=Fényképelrendezés szerkesztő
Name[is]=Ljósmyndauppsetningarforrit
Name[it]=Editor di impaginazioni di foto
Name[km]=កម្មវិធី​កែសម្រួល​ប្លង់​រូបថត
Name[nb]=Fotoutleggsredigerer
Name[nl]=Foto-indelingbewerker
Name[pl]=Edytor układów zdjęć
Name[pt]=Editor de Formatos de Fotografias
Name[pt_BR]=Editor de formatos de fotos
Name[sl]=Urejevalnik Photo Layouts
Name[sv]=Fotolayouteditor
Name[uk]=Редактор компонування фотографій
Name[x-test]=xxPhoto Layouts Editorxx
Name[zh_TW]=相片佈局編輯器
Comment=Photo layouts management tool
Comment[ca]=Eina de gestió de presentacions de foto
Comment[ca@valencia]=Eina de gestió de formats de foto
Comment[cs]=Nástroj pro správu rozvržení snímků
Comment[da]=Håndteringsværktøj til fotolayout
Comment[de]=Programm für Fotolayouts
Comment[el]=Εργαλείο διαχείρισης διατάξεων φωτογραφιών
Comment[es]=Herramienta de gestión de formatos de fotos
Comment[et]=Fotode paigutuse haldur
Comment[gl]=Ferramenta de xestión de disposición de fotos
Comment[hu]=Fényképelrendezés-kezelő eszköz
Comment[is]=Verkfæri til uppsetningar ljósmynda
Comment[it]=Strumento di impaginazione di foto
Comment[km]=ឧបករណ៍​គ្រប់គ្រង​ប្លង់​រូបថត
Comment[nb]=Verktøy for å behandle foto-utforminger
Comment[nl]=Foto-indelingenbeheerder
Comment[pl]=Narzędzie zarządzania układami zdjęć
Comment[pt]=Ferramenta de gestão de formatos de fotografias
Comment[pt_BR]=Ferramenta de gerenciamento de formatos de fotos
Comment[sl]=Orodje za upravljanje z razporeditvami fotografij
Comment[sv]=Hanteringsverktyg för fotolayout
Comment[uk]=Інструмент керування фотокомпозиціями
Comment[x-test]=xxPhoto layouts management toolxx
Comment[zh_TW]=相片佈局管理工具
Icon=photolayoutseditor
ServiceTypes=KIPI/Plugin
Type=Service
X-KDE-Library=kipiplugin_photolayoutseditor
X-KIPI-PluginCategories=Tools
author=Łukasz Spas, lukasz dot spas at gmail dot com

==> digikam-3.3.0-beta1.tar.bz2: digikam-3.3.0-beta1/extra/kipi-plugins/photolayoutseditor/plugin/kipiplugin_photolayoutseditor.desktop.cmake <==
[Desktop Entry]
UntranslatedGenericName=Photo Layouts Editor
Name=Photo Layouts Editor
Name[ca]=Editor de presentacions de foto
Name[ca@valencia]=Editor de presentacions de foto
Name[cs]=Editor rozvržení snímků
Name[da]=Editor til fotolayout
Name[de]=Fotolayout-Editor
Name[el]=Επεξεργαστής διατάξεων φωτογραφιών
Name[es]=Editor de formatos de fotos
Name[et]=Fotode paigutusredaktor
Name[fr]=Éditeur de dispositions de photos
Name[gl]=Editor das disposicións das fotos
Name[hu]=Fényképelrendezés szerkesztő
Name[is]=Ljósmyndauppsetningarforrit
Name[it]=Editor di impaginazioni di foto
Name[km]=កម្មវិធី​កែសម្រួល​ប្លង់​រូបថត
Name[nb]=Fotoutleggsredigerer
Name[nl]=Foto-indelingbewerker
Name[pl]=Edytor układów zdjęć
Name[pt]=Editor de Formatos de Fotografias
Name[pt_BR]=Editor de formatos de fotos
Name[sl]=Urejevalnik razporedov slik
Name[sv]=Fotolayouteditor
Name[uk]=Редактор компонування фотографій
Name[x-test]=xxPhoto Layouts Editorxx
Name[zh_TW]=相片佈局編輯器
Comment=Photo layouts management tool
Comment[ca]=Eina de gestió de presentacions de foto
Comment[ca@valencia]=Eina de gestió de presentacions de foto
Comment[cs]=Nástroj pro správu rozvržení snímků
Comment[da]=Håndteringsværktøj til fotolayout
Comment[de]=Programm für Fotolayouts
Comment[el]=Εργαλείο διαχείρισης διατάξεων φωτογραφιών
Comment[es]=Herramienta de gestión de formatos de fotos
Comment[et]=Fotode paigutuse haldur
Comment[fr]=Outil de l'éditeur de dispositions de photos pour les bordures
Comment[gl]=Ferramenta de xestión de disposición de fotos
Comment[hu]=Fényképelrendezés-kezelő eszköz
Comment[is]=Verkfæri til uppsetningar ljósmynda
Comment[it]=Strumento di impaginazione di foto
Comment[km]=ឧបករណ៍​គ្រប់គ្រង​ប្លង់​រូបថត
Comment[nb]=Verktøy for å behandle foto-utforminger
Comment[nl]=Foto-indelingenbeheerder
Comment[pl]=Narzędzie zarządzania układami zdjęć
Comment[pt]=Ferramenta de gestão de formatos de fotografias
Comment[pt_BR]=Ferramenta de gerenciamento de formatos de fotos
Comment[sl]=Orodje za upravljanje z razporeditvami fotografij
Comment[sv]=Hanteringsverktyg för fotolayout
Comment[uk]=Інструмент керування фотокомпозиціями
Comment[x-test]=xxPhoto layouts management toolxx
Comment[zh_TW]=相片佈局管理工具
Icon=photolayoutseditor
ServiceTypes=KIPI/Plugin
Type=Service
X-KDE-Library=kipiplugin_photolayoutseditor
X-KIPI-PluginCategories=Tools
X-KIPI-BinaryVersion=${KIPI_SO_VERSION}
author=Łukasz Spas, lukasz dot spas at gmail dot com
